@@ -6,6 +6,8 @@ import numpy as np
 import pandas as pd
 from PIL import Image
 from tiatoolbox.dataloader import wsireader
+from skimage.color import rgb2hed
+from skimage.exposure import rescale_intensity
 
 from ..helper import helper
 
@@ -313,6 +315,7 @@ class ReadFromImageFile(Reader):
         return_image_size=None,
         x_column: str = "__x__",
         y_column: str = "__y__",
+        convert_rgb2hed: bool = False,
     ):
         """
         TODO
@@ -331,6 +334,7 @@ class ReadFromImageFile(Reader):
         self.return_image_size = return_image_size
         self.x_column = x_column
         self.y_column = y_column
+        self.convert_rgb2hed = convert_rgb2hed
 
     def crop(self, img, x, y):
         """
@@ -367,7 +371,18 @@ class ReadFromImageFile(Reader):
             return img_black_boarder
         else:
             return img
-
+        
+        
+    def rgb2hed(self, img):
+        ihc_hed = rgb2hed(img)
+        haematoxylin = rescale_intensity(ihc_hed[:, :, 0], out_range=(0, 1),
+                          in_range=(0, np.percentile(ihc_hed[:, :, 0], 99.5)))
+        eosin = rescale_intensity(ihc_hed[:, :, 1], out_range=(0, 1),
+                          in_range=(0, np.percentile(ihc_hed[:, :, 1], 99.5)))
+        dab = rescale_intensity(ihc_hed[:, :, 2], out_range=(0, 1),
+                          in_range=(0, np.percentile(ihc_hed[:, :, 2], 99.5)))
+        return np.stack((haematoxylin, eosin, dab), axis=-1)
+        
     def load_from_row(self, row, path_to_image):
         """
         TODO
@@ -386,6 +401,8 @@ class ReadFromImageFile(Reader):
         img = np.array(Image.open(path_to_file))
         if len(img.shape) == 3 and img.shape[-1] == 4:
             img = img[..., :3]
+        if self.convert_rgb2hed:
+            img = self.rgb2hed(img)
         if self.return_image_size:
             if self.x_column in row:
                 x = row[self.x_column]
