@@ -47,6 +47,36 @@ class BoundingBoxToCenterCoordinates(DataFrameManipulator):
         return df
 
 
+class EditDFImageFilter(DataFrameManipulator):
+    """
+    TODO
+    """
+    def __init__(self, min_std):
+        super().__init__()
+        
+        
+    def __call__(self, df, path_to_image: str, reader):
+        """
+        TODO
+
+        Arguments:
+            df: TODO
+            path_to_image: TODO
+            reader: TODO
+
+        Returns:
+            TODO: TODO
+        """
+        import matplotlib.pyplot as plt
+        for index, row in df.iterrows():
+            img = reader(row, path_to_image)
+            img = img[int(img.shape[0]*0.25):int(img.shape[0]*0.75),int(img.shape[1]*0.25):int(img.shape[1]*0.75)]
+            img_max_red_blue = (np.array(img[:,:,0],dtype=float)<235) | (np.array(img[:,:,1],dtype=float)<150)
+            max_red_blue = np.sum(img_max_red_blue) / (img.shape[0] * img.shape[1])
+            if max_red_blue < 0.25:
+                df.drop(index, inplace=True)
+        return df
+    
 class EditDFImageGrid(DataFrameManipulator):
     """
     TODO
@@ -74,8 +104,6 @@ class EditDFImageGrid(DataFrameManipulator):
         Arguments:
             im_size1d: TODO
 
-        Returns:
-            TODO: TODO
         """
 
         im_size_center = im_size1d - self.return_image_size
@@ -83,7 +111,7 @@ class EditDFImageGrid(DataFrameManipulator):
         locations = np.arange(0, im_size_center + 0.0001, shift)
 
         return np.array(locations + (im_size1d - locations[-1]) / 2, dtype=int)
-
+    
     def __call__(self, df, path_to_image: str, reader):
         """
         TODO
@@ -314,7 +342,93 @@ class EditDFWSIGrid(DataFrameManipulator):
 
         return pd.DataFrame(rows)
 
+    
+class RandomDataSetSplitFilter(DataFrameManipulator):
+    """
+    TODO
+    """
 
+    def __init__(self, num_of_folds, folds_to_use, seed=None, name_of_fold_column='__folds__'):
+        """
+        TODO
+
+        Arguments:
+            percentage_to_filter: TODO
+            mode: TODO
+            seed: TODO
+
+        """
+        DataFrameManipulator.__init__(self)
+        self.num_of_folds = num_of_folds
+        self.folds_to_use = folds_to_use
+        self.seed = seed
+        self.name_of_fold_column = name_of_fold_column
+
+    def __call__(self, df, path_to_image, reader):
+        """
+        TODO
+
+        Arguments:
+            df: TODO
+            path_to_image: Absolute path to image.
+            reader: TODO
+
+        Returns:
+            TODO: TODO
+        """
+        if self.name_of_fold_column not in df:
+            rng = np.random.default_rng(self.seed)
+            df[self.name_of_fold_column] = rng.integers(self.num_of_folds, size=len(df))
+        
+        return df[df[self.name_of_fold_column].isin(self.folds_to_use)]
+    
+
+class RandomDataSetSplitFilterByColumnValue(DataFrameManipulator):
+    """
+    TODO
+    """
+
+    def __init__(self, column, num_of_folds, folds_to_use, seed=None, name_of_fold_column='__folds__'):
+        """
+        TODO
+
+        Arguments:
+            percentage_to_filter: TODO
+            mode: TODO
+            seed: TODO
+
+        """
+        DataFrameManipulator.__init__(self)
+        self.column = column
+        self.num_of_folds = num_of_folds
+        self.folds_to_use = folds_to_use
+        self.seed = seed
+        self.name_of_fold_column = name_of_fold_column
+
+    def __call__(self, df, path_to_image, reader):
+        """
+        TODO
+
+        Arguments:
+            df: TODO
+            path_to_image: Absolute path to image.
+            reader: TODO
+
+        Returns:
+            TODO: TODO
+        """
+        if self.name_of_fold_column not in df:
+            rng = np.random.default_rng(self.seed)
+            g = df.groupby(self.column)
+            random_numbers = rng.integers(self.num_of_folds, size=len(g.indices.keys()))
+            folds = np.zeros(len(df), dtype=int)
+            for k, r in zip(g.indices, random_numbers):
+                folds[g.indices[k]] = r
+            df[self.name_of_fold_column] = folds
+        
+        return df[df[self.name_of_fold_column].isin(self.folds_to_use)]
+    
+    
 class DataFrameFilter:
     """
     TODO
@@ -350,6 +464,52 @@ class DataFrameFilter:
             return df.loc[indices], df.loc[~df.index.isin(indices)]
 
 
+
+        
+class HematoxylinFilter(DataFrameFilter, DataFrameManipulator):
+    """
+    TODO
+    """
+
+    def __init__(self, image_size, mode=0):
+        """
+        TODO
+
+        Arguments:
+            percentage_to_filter: TODO
+            mode: TODO
+            seed: TODO
+
+        """
+        DataFrameFilter.__init__(self, mode)
+        DataFrameManipulator.__init__(self)
+        from skimage.color import rgb2hed, hed2rgb
+        self.center_start = image_size - (image_size/(2**0.5))
+        
+    def hematoxylin_filter(self, patch):
+        ihc_hed = rgb2hed(patch[128:512-128,128:512-128])
+        return np.mean(ihc_hed[:, :, 0] > 0.05) > 0.03
+    
+    def __call__(self, df, path_to_dataset, reader):
+        """
+        TODO
+
+        Arguments:
+            df: TODO
+            path_to_image: Absolute path to image.
+            reader: TODO
+
+        Returns:
+            TODO: TODO
+        """
+        indices = []
+        for index, row in df.iterrows():
+            loaded = reader(row, path_to_dataset)
+            if self.hematoxylin_filter(loaded):
+                indices.append(index)
+        return DataFrameFilter.__call__(self, df, indices)
+        
+
 class RandomFilter(DataFrameFilter, DataFrameManipulator):
     """
     TODO
@@ -431,7 +591,7 @@ class RandomFilterByColumnValue(DataFrameFilter, DataFrameManipulator):
         return DataFrameFilter.__call__(self, df, indices)
 
 
-class LambdaFilter(DataFrameFilter, DataFrameManipulator):
+class LambdaRowFilter(DataFrameFilter, DataFrameManipulator):
     """
     TODO
     """
@@ -465,6 +625,38 @@ class LambdaFilter(DataFrameFilter, DataFrameManipulator):
         return DataFrameFilter.__call__(self, df, df[df.apply(self.lambda_function, 1)].index)
 
 
+class LambdaDFFilter(DataFrameManipulator):
+    """
+    TODO
+    """
+
+    def __init__(self, lambda_function):
+        """
+        TODO
+
+        Arguments:
+            lambda_function: TODO
+            mode: TODO
+
+        """
+        DataFrameManipulator.__init__(self)
+        self.lambda_function = lambda_function
+
+    def __call__(self, df, path_to_image, reader):
+        """
+        TODO
+
+        Arguments:
+            df: TODO
+            path_to_image: Absolute path to image.
+            reader: TODO
+
+        Returns:
+            TODO: TODO
+        """
+        return self.lambda_function(df)
+    
+    
 class ColumnFilter(DataFrameFilter, DataFrameManipulator):
     """
     TODO
