@@ -41,9 +41,9 @@ def mai_patches(
         subset: which part of the dataset should be used.
                        One of {"train", "validation", "test", "all"}
                        This parameter is only used if folds is not set.
-                       "train" equals folds: [0,1,2,3,4,5,6],
-                       "validation" equals folds: [7,8],
-                       "test" equals folds: [9]
+                       "train" equals folds: [0,1,2,3,4,5,6] (size: 2824),
+                       "validation" equals folds: [7,8] (size: 807),
+                       "test" equals folds: [9] (size: 367)                       
         gt_mode (str): The pathologist take a look at the slides three times
                        (GT1, GT2, GT3). One of the following modes are allowed:
                        - "GT1": 'None-Mitosis' / 'Mitosis' from the first study
