@@ -19,6 +19,7 @@ def midog_classification_patches(
     splitting_seed: int = 1,
     scanner_to_use: O[U[int, list]] = None,
     seed: O[int] = None,
+    convert_rgb2hed: O[bool] = False,
 ) -> HistoDataset:
     """
     Creates the MIDOG classification dataset and returns it as type HistoDataset, which inherits from torch.utils.data.Dataset.
@@ -72,23 +73,23 @@ def midog_classification_patches(
             non-mitotic.
     """
     manipulators_to_use = []
-    
+
     # handle training, validation and test cases
     if subset:
         subset = subset.lower()
     if subset.startswith("tr"):
-        folds_to_use = [0,1]
+        folds_to_use = [0, 1]
     elif subset.startswith("val"):
         folds_to_use = [2]
-    elif subset.startswith("te"):  
+    elif subset.startswith("te"):
         folds_to_use = [3]
     elif subset == "all":
-        folds_to_use = [0,1,2,3]
+        folds_to_use = [0, 1, 2, 3]
     else:
         raise NotImplementedError(
             'The parameter "subset" needs to be one of ["train", "validation", "test", "all"].'
         )
-    
+
     """
     # If this is used instead of the following, then each large original image, will be
     # set to one of the subsets with all the datapoints in it.
@@ -121,7 +122,7 @@ def midog_classification_patches(
     manipulators_to_use.append(df_manipulators.BoundingBoxToCenterCoordinates("bbox"))
 
     data_reader = data_readers.ReadFromImageFile(
-        "images/{image_id:03d}.tiff", return_image_size=patch_size
+        "images/{image_id:03d}.tiff", return_image_size=patch_size, convert_rgb2hed=convert_rgb2hed
     )
 
     # create HistoDataset object and pass relevant attributes
@@ -216,15 +217,15 @@ def midog_classification_patches_preprocessed(
         subset = subset.lower()
     if subset.startswith("tr"):
         df_manipulator = df_manipulators.ColumnFilter(
-            name_of_column='__folds__', allowed_values=[0,1]
+            name_of_column="__folds__", allowed_values=[0, 1]
         )
     elif subset.startswith("val"):
         df_manipulator = df_manipulators.ColumnFilter(
-            name_of_column='__folds__', allowed_values=[2]
+            name_of_column="__folds__", allowed_values=[2]
         )
     elif subset.startswith("te"):
         df_manipulator = df_manipulators.ColumnFilter(
-            name_of_column='__folds__', allowed_values=[3]
+            name_of_column="__folds__", allowed_values=[3]
         )
     elif subset.startswith("all"):
         df_manipulator = None
